==> tswlib-1.0.0.tgz: package/UpdateQueue.js <==
let _updateQueue = null;
let _timerId;
let _updatedCbs = [];
export function addToUpdateQueue(ctxs) {
    if (_updateQueue == null) {
        _updateQueue = ctxs;
    }
    else {
        const updateQueue = _updateQueue;
        ctxs.forEach(ctx => {
            updateQueue.add(ctx);
        });
    }
    if (_updateQueue.size > 0 && _timerId == null) {
        _timerId = requestAnimationFrame(processQueue);
    }
}
export function removeFromUpdateQueue(ctx) {
    if (_updateQueue) {
        _updateQueue.delete(ctx);
    }
}
function processQueue() {
    const updateQueue = _updateQueue;
    _timerId = undefined;
    _updateQueue = null;
    if (updateQueue) {
        if (updateQueue.size == 1) {
            updateQueue.forEach(ctx => {
                ctx.update();
            });
        }
        else {
            const contextsToUpdate = getContextsToUpdate(updateQueue);
            for (let ctx of contextsToUpdate) {
                ctx.update();
            }
        }
    }
    const updatedCbs = _updatedCbs;
    _updatedCbs = [];
    for (let cb of updatedCbs) {
        cb();
    }
}
function getContextsToUpdate(updateQueue) {
    const contextsToUpdate = [];
    updateQueue.forEach(ctx => {
        if (!isAnyParentInQueue(ctx, updateQueue)) {
            contextsToUpdate.push(ctx);
        }
    });
    return contextsToUpdate;
}
function isAnyParentInQueue(ctx, updateQueue) {
    while (true) {
        const ctxParent = ctx.getParent();
        if (!ctxParent)
            return false;
        if (updateQueue.has(ctxParent))
            return true;
        ctx = ctxParent;
    }
}
export function afterDOMUpdated(cb) {
    if (_timerId != null) {
        _updatedCbs.push(cb);
    }
    else {
        cb();
    }
}
export function applyChanges() {
    if (_timerId != undefined) {
        cancelAnimationFrame(_timerId);
        _timerId = undefined;
    }
    processQueue();
}

==> tswlib-1.4.0.tgz: package/UpdateQueue.js <==
let _updateQueue = null;
let _timerId;
let _updatedCbs = [];
export function addToUpdateQueue(ctxs) {
    if (_updateQueue == null) {
        _updateQueue = ctxs;
    }
    else {
        const updateQueue = _updateQueue;
        ctxs.forEach(ctx => {
            updateQueue.add(ctx);
        });
    }
    if (_updateQueue.size > 0 && _timerId == null) {
        _timerId = requestAnimationFrame(processQueue);
    }
}
export function removeFromUpdateQueue(ctx) {
    if (_updateQueue) {
        _updateQueue.delete(ctx);
    }
}
function processQueue() {
    const updateQueue = _updateQueue;
    _timerId = undefined;
    _updateQueue = null;
    if (updateQueue) {
        if (updateQueue.size == 1) {
            updateQueue.forEach(ctx => {
                ctx.update();
            });
        }
        else {
            const contextsToUpdate = getContextsToUpdate(updateQueue);
            for (const ctx of contextsToUpdate) {
                ctx.update();
            }
        }
    }
    const updatedCbs = _updatedCbs;
    _updatedCbs = [];
    for (const cb of updatedCbs) {
        cb();
    }
}
function getContextsToUpdate(updateQueue) {
    const contextsToUpdate = [];
    updateQueue.forEach(ctx => {
        if (!isAnyParentInQueue(ctx, updateQueue)) {
            contextsToUpdate.push(ctx);
        }
    });
    return contextsToUpdate;
}
function isAnyParentInQueue(ctx, updateQueue) {
    while (true) {
        const ctxParent = ctx.getParent();
        if (!ctxParent)
            return false;
        if (updateQueue.has(ctxParent))
            return true;
        ctx = ctxParent;
    }
}
export function afterDOMUpdated(cb) {
    if (_timerId != null) {
        _updatedCbs.push(cb);
    }
    else {
        cb();
    }
}
export function applyChanges() {
    if (_timerId != undefined) {
        cancelAnimationFrame(_timerId);
        _timerId = undefined;
    }
    processQueue();
}
